==> haskell-ieee754-0.8.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ieee754
version:              0.8.0
visibility:           public
id:                   ieee754-0.8.0-8ARR0f1c99A76lnIcdz1Si
key:                  ieee754-0.8.0-8ARR0f1c99A76lnIcdz1Si
license:              BSD-3-Clause
copyright:            (c) 2011-2016. Patrick Perry <patperry@gmail.com>
maintainer:           Patrick Perry <patperry@gmail.com>
author:               Patrick Perry
homepage:             http://github.com/patperry/hs-ieee754
synopsis:             Utilities for dealing with IEEE floating point numbers
description:
    Utilities for dealing with IEEE floating point numbers, ported
    from the Tango math library; approximate and exact equality
    comparisons for general types.

category:             Math
abi:                  aa412a8e206bd7ff03aa7d14c6411ab2
exposed:              True
exposed-modules:      Data.AEq Numeric.IEEE
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ieee754-0.8.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ieee754-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/ieee754-0.8.0
hs-libraries:         HSieee754-0.8.0-8ARR0f1c99A76lnIcdz1Si
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-ieee754/html/ieee754.haddock
haddock-html:         /usr/share/doc/haskell-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ieee754-0.8.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ieee754
version:              0.8.0
visibility:           public
id:                   ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
key:                  ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
license:              BSD-3-Clause
copyright:            (c) 2011-2016. Patrick Perry <patperry@gmail.com>
maintainer:           Patrick Perry <patperry@gmail.com>
author:               Patrick Perry
homepage:             http://github.com/patperry/hs-ieee754
synopsis:             Utilities for dealing with IEEE floating point numbers
description:
    Utilities for dealing with IEEE floating point numbers, ported
    from the Tango math library; approximate and exact equality
    comparisons for general types.

category:             Math
abi:                  805688769b035d94979e76411ff3e14f
exposed:              True
exposed-modules:      Data.AEq Numeric.IEEE
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ieee754-0.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ieee754-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ieee754
hs-libraries:         HSieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-ieee754/html/ieee754.haddock
haddock-html:         /usr/share/doc/haskell-ieee754/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
